/* Variables
------------------------------------------------------------------
{
  Color: [
    {
      value: 'blue',
      sample: '#3681c1',
      NormalColor: '#3681c1',
      HoverColor: '#80c5ff',
	  SubNavColor: '#aad8ff',
	  BorderNavColor: '#8ecbff',
	  LandingNormalColor: '#80c5ff',
	  LandingHoverColor: '#8cddff'
    },
    {
      value: 'green',
      sample: '#6cbf2f',
      NormalColor: '#6cbf2f',
      HoverColor: '#8fd55c',
	  SubNavColor: '#a2e373',
	  BorderNavColor: '#95da64',
	  LandingNormalColor: '#9eec66',
	  LandingHoverColor: '#b4fc80'
    },
    {
      value: 'orange',
      sample: '#fe971d',
      NormalColor: '#fe971d',
      HoverColor: '#fdb259',
	  SubNavColor: '#ffc279',
	  BorderNavColor: '#feb764',
	  LandingNormalColor: '#ffd39e',
	  LandingHoverColor: '#ffdcb3'
    },
    {
      value: 'pink',
      sample: '#cf4596',
      NormalColor: '#cf4596',
      HoverColor: '#f772c0',
	  SubNavColor: '#fc8dce',
	  BorderNavColor: '#f97bc5',
	  LandingNormalColor: '#ff8acf',
	  LandingHoverColor: '#ffacdd'
    },
    {
      value: 'purple',
      sample: '#9958b4',
      NormalColor: '#9958b4',
      HoverColor: '#bb7ed4',
	  SubNavColor: '#d192eb',
	  BorderNavColor: '#c285dc',
	  LandingNormalColor: '#d697f0',
	  LandingHoverColor: '#e8afff'
    },
    {
      value: 'red',
      sample: '#cd2727',
      NormalColor: '#cd2727',
      HoverColor: '#eb4747',
	  SubNavColor: '#fd5f5f',
	  BorderNavColor: '#f14f4f',
	  LandingNormalColor: '#f87070',
	  LandingHoverColor: '#ffa6a6'
    },
    {
      value: 'teal',
      sample: '#33ab9e',
      NormalColor: '#33ab9e',
      HoverColor: '#4dd3c4',
	  SubNavColor: '#7ce3d7',
	  BorderNavColor: '#5dd8ca',
	  LandingNormalColor: '#6fd7cb',
	  LandingHoverColor: '#8eebe0'
    }
  ]
}
------------------------------------------------------------------
*/


/* Resets
--------------------------------------------------------------------------------*/

ul, ol, li, h1, h2, h3, h4, h5, h6, pre, form, body, html, p, blockquote, fieldset, input {
	margin: 0;
	padding: 0;
}

a img {
	border: 0;
}

a {
	color: $NormalColor;
	text-decoration: none;
}

a:hover {
	color: $HoverColor;
}

/* General Styling and Structure
--------------------------------------------------------------------------------*/

body {
	font-family: Arial, Helvetica, sans-serif;
	font-size: 13px;
	color: #8e8e8e;
	margin: 0;
	background: url(body-bg.jpg) center top;
	padding: 0 0 50px;
}

h2 {
	font-size: 1.4em;
	margin: 0;
	padding: .3em 0;
	line-height: 1.2;
	font-family: "Maven Pro", "Myriad Pro", Arial, Helvetica, sans-serif;
	font-weight: bold;
	text-transform: uppercase;
}

#content h2 {
	color: $NormalColor;
}

p {
	font-size: 1em;
	line-height: 1.5;
	margin: 0;
	padding: .5em 0;
}
blockquote {
	font-style:italic;
	border-left:4px solid $normalColor;
	margin:10px 0 10px 0;
	padding-left:20px;
	line-height:1.5;
	color:#aaa;
}

#content p {
	color: #8e8e8e;
}

#content abbr {
	border-bottom: 1px dotted #8f8f8f;
}

#container {
	margin: 0 auto;
	width: 900px;
}

#header {
	padding: 0;
	margin: 0;
}

.wsite-logo,
.wsite-logo a {
	color: $NormalColor;
	text-decoration: none;
}

.wsite-logo,
.wsite-logo a:hover {
	color: $NormalColor;
}

.wsite-logo {
	font-size: 30px;
	color: #3681c1;
	font-weight: bold;
	font-family: "Maven Pro", "Myriad Pro", Arial, Helvetica, sans-serif;
	text-transform: uppercase;
}

#header-right a {
	color: $NormalColor;
}

#header-right a:hover {
	color: $HoverColor;
}

/* Header Area
----------------------------------------------------------------------------*/

#header-top {
	padding: 20px 0;
	clear: both;
}

#header-right {
	float: right;
}

#header {
	width: 100%;
	height: 100px;
}

#header,
#header table {
	border-collapse: collapse;
	border-spacing: 0;
}

#header td {
	vertical-align: middle;
	text-align: left;
}

#logo {
	padding: 25px 0;
}

/* TOP RIGHT: Phone Number
--------------------------------------------------------------------------------*/

#header-right .phone-number .wsite-text {
	color: #6d6d6d;
	font-size: 12px;
	font-weight: normal;
	font-family: Arial, Helvetica, sans-serif;
	text-decoration: none;
	display: block;
	white-space: nowrap;
	margin: 2px 0 0 15px;
}

/* TOP RIGHT: Social Links
--------------------------------------------------------------------------------*/

#header-right .wsite-social {
	vertical-align: middle;
	margin: 0 0 0 5px;
}


.wsite-social-item {
	width: 20px;
	height: 20px;
	margin: 0 0 0 3px;
	background-image:url(social-no-container-dark.png);
}

.wsite-social-facebook {background-position:0 0;}
	.wsite-social-facebook:hover {background-position:0 -20px;}
	.wsite-social-facebook:active {background-position:0 -40px;}
.wsite-social-pinterest {background-position:-20px 0;}
	.wsite-social-pinterest:hover {background-position:-20px -20px;}
	.wsite-social-pinterest:active {background-position:-20px -40px;}
.wsite-social-twitter {background-position:-40px 0;}
	.wsite-social-twitter:hover {background-position:-40px -20px;}
	.wsite-social-twitter:active {background-position:-40px -40px;}
.wsite-social-linkedin {background-position:-60px 0;}
	.wsite-social-linkedin:hover {background-position:-60px -20px;}
	.wsite-social-linkedin:active {background-position:-60px -40px;}
.wsite-social-mail {background-position:-80px 0;}
	.wsite-social-mail:hover {background-position:-80px -20px;}
	.wsite-social-mail:active {background-position:-80px -40px;}
.wsite-social-rss {background-position:-100px 0;}
	.wsite-social-rss:hover {background-position:-100px -20px;}
	.wsite-social-rss:active {background-position:-100px -40px;}
.wsite-social-flickr {background-position:-120px 0;}
	.wsite-social-flickr:hover {background-position:-120px -20px;}
	.wsite-social-flickr:active {background-position:-120px -40px;}
.wsite-social-plus {background-position:-140px 0;}
	.wsite-social-plus:hover {background-position:-140px -20px;}
	.wsite-social-plus:active {background-position:-140px -40px;}
.wsite-social-vimeo {background-position:-160px 0;}
	.wsite-social-vimeo:hover {background-position:-160px -20px;}
	.wsite-social-vimeo:active {background-position:-160px -40px;}
.wsite-social-yahoo {background-position:-180px 0;}
	.wsite-social-yahoo:hover {background-position:-180px -20px;}
	.wsite-social-yahoo:active {background-position:-180px -40px;}
.wsite-social-youtube {background-position:-200px 0;}
	.wsite-social-youtube:hover {background-position:-200px -20px;}
	.wsite-social-youtube:active {background-position:-200px -40px;}


/* TOP RIGHT: Search Box
--------------------------------------------------------------------------------*/

#header-right .search {
}

#header-right .wsite-search {
	margin: 0 0 0 15px;
	vertical-align: middle;
}

#header-right .wsite-search-input {
	width: 144px;
	height: 14px;
	border: none;
	padding: 6px 5px 7px 10px !important;
	color: #575757;
	font-size: 12px;
	background: url(input-bg.png) no-repeat;
}

#header-right .wsite-search-button {
	position: relative;
	width: 24px;
	height: 27px;
	color: #010101;
	font-size: 12px;
	border: none;
	margin: 0;
	padding: 0;
	background: url(submit-bg-$Color.png) no-repeat;
}

/* Navigation
--------------------------------------------------------------------------------*/

#top-section {
	padding: 0 0 0 30px;
	background: #fff;
}

#header #header-nav {
	padding: 0 20px 0 30px;
	text-align: right;
}

#header-nav ul {
	display: inline;
	list-style: none;
}

#header-nav ul li {
	display: inline;
}

#header-nav a {
	display: inline-block;
	vertical-align: middle;
	color: #181818;
	text-decoration: none;
	font-family: "Maven Pro", "Myriad Pro", Arial, Helvetica, sans-serif;
	font-weight: 500;
	padding: 11px 12px;
	border: 0;
	outline: 0;
	overflow: hidden;
	list-style-type: none;
	font-size: 13px;
	text-transform: uppercase;
}

#header-nav li#active a,
#header-nav a:hover {
	color: #fff;
	background: $HoverColor;
	border: 0;
}

/****************************** flyout menus ******************************/

#wsite-menus .wsite-menu li a {
	font-family: Arial, Helvetica, sans-serif;
	padding: 10px;
	color: #fff;
	background: $HoverColor;
	border: 0;
	border-bottom: 1px solid $HoverColor;
	text-decoration: none;
}

#wsite-menus .wsite-menu li a:hover {
	color: #fff;
	background: $SubNavColor;
	border-bottom: 1px solid $BorderNavColor;
}

/* main  */

#main {
}

#content {
	background: #fff;
	min-height: 400px;
	padding: 35px 30px;
}

#banner {
	position: relative;
}

/* PAGE TYPE: banner-tall
--------------------------------------------------------------------------------*/

.tall-header-page .wsite-header {
	width: 900px;
	height: 270px;
	background: url(banner-tall.jpg) no-repeat;
}

/* PAGE TYPE: banner-short
--------------------------------------------------------------------------------*/

.short-header-page .wsite-header {
	width: 900px;
	height: 170px;
	background: url(banner-short.jpg) no-repeat;
}

/* PAGE TYPE: no-header
--------------------------------------------------------------------------------*/

.no-header-page #main {
	border-top: 9px solid #f4f4f4;
}

.no-header-page #content {
	padding-top: 30px;
}

/* PAGE TYPE: banner-landing
--------------------------------------------------------------------------------*/

.landing-page #banner {
	background: $NormalColor;
	overflow: hidden;
}

#bannerleft {
	float: right;
	padding: 0;
	position: relative;
}

.landing-page .wsite-header {
	width: 540px;
	height: 330px;
	background: url(banner-landing.jpg) no-repeat;
}

.landing-banner-outer {
	display: table;
	#position: relative;
	overflow: hidden;
}

.landing-banner-mid {
	#position: absolute;
	#top: 50%;
	display: table-cell;
	vertical-align: middle;
}

.landing-banner-inner {
	#position: relative;
	#top: -50%;
}

#bannerright {
	float: right;
	width: 295px;
	height: 330px;
	padding: 0 35px 0 30px;
}

#bannerright h2 {
	color: #ffffff;
	font-size: 24px;
	padding: 0px;
	line-height: 24px;
}

#bannerright p {
	color: #e8e8e8;
	font-size: 14px;
	padding: 20px 0px;
	line-height: 140%;
	margin: 0;
}

#bannerright a {
	color: $LandingNormalColor;
}

#bannerright a:hover {
	color: $LandingHoverColor;
}

#bannerright .wsite-button {
	margin: 0;
}

/* PAGE TYPE: splash
--------------------------------------------------------------------------------*/

.splash-page #header {
	width: 532px;
}

.splash-page #banner {
	width: 527px;
	height: 161px;
	padding: 6px 4px 4px 6px;
	background: url(banner-splash-bg.png) no-repeat;
}

.splash-page .wsite-header {
	width: 515px;
	height: 149px;
	background: url(banner-splash.jpg) no-repeat;
}

.splash-page #content-container {
	width: 528px;
}

.splash-page #content {
	width: 528px;
}

.splash-page #footer {
	width: 524px;
}

/* Footer
--------------------------------------------------------------------------------*/

#footer {
	border-top: 9px solid #f4f4f4;
	padding: 40px 40px 43px;
	font-size: 12px;
	color: #414141;
	font-family: Arial, Helvetica, sans-serif;
	text-align: right;
	background: #fff;
}

#footer p {
	color: #414141;
}

#footer h2 {
	font-size: 16px;
	padding: .3em 0;
	line-height: 1.5;
	font-family: "Maven Pro", "Myriad Pro", Arial, Helvetica, sans-serif;
	color: $NormalColor;
	border-bottom:1px solid #ddd;
}

#footer span {
	vertical-align: middle;
}

.wsite-footer {  /* make sure enough space between element footer and attribution */
	margin-bottom: 15px;
}

/* Form Customization
--------------------------------------------------------------------------------*/

.wsite-form-label {
	display: inline-block;
	color: #8e8e8e;
	font-family: Arial, Helvetica, sans-serif;
	font-size: 1em;
	padding: 12px 0 5px 0;
}

.form-radio-container {
	color: #8e8e8e;
	font-size: 1em;
	font-family: Arial, Helvetica, sans-serif;
}

.wsite-form-input, .wsite-search-element-input {
	font-family: Arial, Helvetica, sans-serif;
	font-size: 1em;
	color: #8e8e8e;
	background: #fff;
	border: 1px solid #dcdcdc;
	padding: 8px 4px 5px !important;
	line-height: 1;
}

.form-select {
	color: #8e8e8e;
	background: #fff;
	border: 1px solid #dcdcdc;
	font-size: 1em;
	font-family: Arial, Helvetica, sans-serif;
	padding: 3px 4px;
	width: 320px;
	height: 27px;
	line-height: 27px;
}

/* Footer Form Customization
--------------------------------------------------------------------------------*/

.wsite-form-container {
	margin-top:0px !important;
	text-align:left;
}

.wsite-footer .wsite-form-label {
	font-size: 1em;
	padding: 5px 0 2px 0;
}

.wsite-footer .wsite-form-field {
	width:300px !important;
}

.wsite-footer .form-radio-container {
	font-size:1em;
}

.wsite-footer .wsite-form-input {
	font-size: 1em;
	width: 100% !important;

}

.wsite-footer .form-select {
	width: 100%;
}

/* Buttons
--------------------------------------------------------------------------------*/

/*
  Buttons are styled with background image sprites. There are 4 unique image files:
   - small & normal-colored  (button_small_grey.png)
   - large & normal-colored  (button_large_grey.png)
   - small & highlight-colored  (button_small_orange.png)
   - large & highlight-colored  (button_large_orange.png)

  Each of these 4 types of buttons must define a :hover state (when user's mouse is over)
  as well as an :active state (when the user presses down).

  Look at the CSS (especially the inner .wsite-button-inner wrapper), as well as the
  image files to understand how the liquid-width nature of these buttons work.
 */

/* small */

.wsite-button {
	color: #fff !important;
	font-family: Arial, Helvetica, sans-serif;
	height: 34px;
	display: inline-block;
	font-size: 12px;
	border: none;
	font-weight: bold;
	font-size: 13px;
	text-decoration: none;
	padding: 0 15px 0 0;
	background: url(button_$Color.png) no-repeat 100% -105px;
	text-shadow:0 -1px 0 rgba(0,0,0,0.9);
}

.wsite-button:hover {
	background-position: 100% -140px;
}

.wsite-button:active {
	background-position: 100% -175px;
}

.wsite-button-inner {
	height: 34px;
	line-height: 34px;
	display: block;
	font-size: 14px;
	font-weight: bold;
	border: none;
	text-decoration: none;
	padding: 0 10px 0 25px;
	background: url(button_$Color.png) no-repeat 0 0;
}

.wsite-button:hover .wsite-button-inner {
	background-position: 0 -35px;
}

.wsite-button:active .wsite-button-inner {
	background-position: 0 -70px;
}

/* large */

.wsite-button-large {
	height: 41px;
	background: url(button_large_$Color.png) no-repeat 100% -126px;
	padding: 0 15px 0 0;
}

.wsite-button-large:hover {
	background-position: 100% -168px;
}

.wsite-button-large:active {
	background-position: 100% -210px;
}

.wsite-button-large .wsite-button-inner {
	height: 41px;
	line-height: 41px;
	padding: 0 10px 0 25px;
	background: url(button_large_$Color.png) no-repeat 0 0;
}

.wsite-button-large:hover .wsite-button-inner {
	background-position: 0 -42px;
}

.wsite-button-large:active .wsite-button-inner {
	background-position: 0 -84px;
}

/* highlight */

/*
Making the highlighted versions of the buttons is easy because we just need
to switch out the background images. This works because the different button
states (normal, :hover, :active) have their sprite coordinates in the same places.
*/

.wsite-button-large.wsite-button-highlight {
	background-image: url(button_large_highlight.png);
}

.wsite-button-large.wsite-button-highlight .wsite-button-inner {
	background-image: url(button_large_highlight.png);
}

.wsite-button-highlight {
	color: #555555 !important;
	background-image: url(button_highlight.png);
	text-shadow:0 1px 0 rgba(255,255,255,0.8);
}

.wsite-button-highlight .wsite-button-inner {
	background-image: url(button_highlight.png);
}
