/* Variables
------------------------------------------------------------------
{
  Color: [
    {
      value: 'gray',
      sample: '#686868',
      LinkColor: '#030303',
	  ButtonText: '#686868',
	  ButtonStartColor: '#7b7b7b',
	  ButtonEndColor: '#545454',
	  PressedStartColor: '#454545',
	  PressedEndColor: '#505050',
	  ButtonBorder: '#000000'
    },
    {
      value: 'orange',
      sample: '#df661e',
      LinkColor: '#df661e',
	  ButtonText: '#df661e',
	  ButtonStartColor: '#e4792f',
	  ButtonEndColor: '#d65316',
	  PressedStartColor: '#9c4414',
	  PressedEndColor: '#a44f1a',
	  ButtonBorder: '#3f1800'
    },
    {
      value: 'royal',
      sample: '#1f569a',
      LinkColor: '#1f569a',
	  ButtonText: '#1f569a',
	  ButtonStartColor: '#306aa8',
	  ButtonEndColor: '#174487',
	  PressedStartColor: '#133665',
	  PressedEndColor: '#1a4373',
	  ButtonBorder: '#001836'
	},
    {
      value: 'pink',
      sample: '#ff5dae',
      LinkColor: '#ff5dae',
	  ButtonText: '#ff5dae',
	  ButtonStartColor: '#ff70ba',
	  ButtonEndColor: '#ff4a9d',
	  PressedStartColor: '#b63e78',
	  PressedEndColor: '#ba4882',
	  ButtonBorder: '#61002e'
    },
    {
      value: 'yellow',
      sample: '#e7ba00',
      LinkColor: '#e7c400',
	  ButtonText: '#e7ba00',
	  ButtonStartColor: '#ebc400',
	  ButtonEndColor: '#e0aa00',
	  PressedStartColor: '#9e7d00',
	  PressedEndColor: '#a98a00',
	  ButtonBorder: '#615200'
    },
    {
      value: 'green',
      sample: '#36b942',
      LinkColor: '#36b942',
	  ButtonText: '#36b942',
	  ButtonStartColor: '#4ac356',
	  ButtonEndColor: '#28a933',
	  PressedStartColor: '#23802b',
	  PressedEndColor: '#2c8935',
	  ButtonBorder: '#005408'
    },
    {
      value: 'blue',
      sample: '#2b85d2',
      LinkColor: '#2b85d2',
	  ButtonText: '#2b85d2',
	  ButtonStartColor: '#3f95d9',
	  ButtonEndColor: '#2071c6',
	  PressedStartColor: '#1b5b92',
	  PressedEndColor: '#24659b',
	  ButtonBorder: '#00539a'
    },
    {
      value: 'red',
      sample: '#cc0000',
      LinkColor: '#cc0000',
	  ButtonText: '#cc0000',
	  ButtonStartColor: '#d40000',
	  ButtonEndColor: '#bf0000',
	  PressedStartColor: '#8f0000',
	  PressedEndColor: '#960000',
	  ButtonBorder: '#830000'
    },
    {
      value: 'purple',
      sample: '#4f74bd',
      LinkColor: '#5872c4',
	  ButtonText: '#4f74bd',
	  ButtonStartColor: '#6c8fcd',
	  ButtonEndColor: '#466ab6',
	  PressedStartColor: '#3b5689',
	  PressedEndColor: '#456091',
	  ButtonBorder: '#1b3b7b'
    }
  ]
}
------------------------------------------------------------------
*/


/** Customized HTML5 reset based on normalize.css and HTML5 boilerplate */

/** Block display fix */
article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
nav,
section,
summary {
	display: block;
}

/** Inline display fix */
audio,
canvas,
video {
	display: inline-block;
	*display: inline;
	*zoom: 1;
}

/** Audio controls fix */
audio:not([controls]) {
	display: none;
	height: 0;
}

/** Hidden attribute support */
[hidden] {
	display: none;
}

/** Text resizing fix */
html {
	font-size: 100%;
	-webkit-text-size-adjust: 100%;
	-ms-text-size-adjust: 100%;
}

/** Font family consistency fix */
html,
button,
input,
select,
textarea {
	font-family: sans-serif;
	color: #222;
}

/** No margins, readable text */
body {
	margin: 0;
	font-size: 13px;
	line-height: 22px;
}

/** Normalize link focus */
a:focus {
	outline: thin dotted;
}

/** Readability fix  */
a:hover,
a:active {
	outline: 0;
}

/** Style normalizing */
abbr[title] {
	border-bottom: 1px dotted;
}

/** Addresses style set to 'bolder' in FF3+, S4/5, Chrome */
b, 
strong {
	font-weight: bold;
}

/** margin normalizing */
blockquote {
	margin: 1em 40px;
}

/** Addresses styling not present in S5, Chrome */
dfn {
	font-style: italic;
}

/** Addresses styling not present in IE6/7/8/9 */
mark {
	background: #ff0;
	color: #000;
}

/** Addresses margins set differently in IE6/7 */
/*p,  TODO: remove? set further down */
pre {
	margin: 1em 0;
}

/** Corrects font family set oddly in IE6, S4/5, Chrome */
pre,
code,
kbd,
samp {
	font-family: monospace, serif;
	_font-family: 'courier new', monospace;
	font-size: 1em;
}

/** Improves readability of pre-formatted text in all browsers */
pre {
	white-space: pre;
	white-space: pre-wrap;
	word-wrap: break-word;
}

/** Quote support */
q {
	quotes: none;
}

q:before,
q:after {
	content: '';
	content: none;
}

/** Normalize */
small {
	font-size: 75%;
}

/** Prevents sub and sup affecting line-height in all browsers */
sub,
sup {
	font-size: 75%;
	line-height: 0;
	position: relative;
	vertical-align: baseline;
}

sup {
	top: -0.5em;
}

sub {
	bottom: -0.25em;
}

/** Addresses margins set differently in IE6/7 */
dl,
menu,
ol,
ul {
	margin: 1em 0;
}

dd {
	margin: 0 0 0 40px;
}

/** Addresses paddings set differently in IE6/7 */
menu,
ol,
ul {
	padding: 0 0 0 40px;
}

/** Corrects list images handled incorrectly in IE7 */
nav ul,
nav ol {
	list-style: none;
	list-style-image: none;
}

/** Normalize border, improve scaling */
img {
	border: 0;
	-ms-interpolation-mode: bicubic;
}

/** Corrects overflow displayed oddly in IE9 */
svg:not(:root) {
	overflow: hidden;
}

/** Addresses margin not present in IE6/7/8/9, S5, O11 */
figure {
	margin: 0;
}

/** Corrects margin displayed oddly in IE6/7 */
form {
	margin: 0;
}

/** Define consistent border, margin, and padding */
fieldset {
	border: 0;
	margin: 0;
	padding: 0;
}

/** Corrects color and alignment issues in IE6/7/8/9 */
legend {
	border: 0;
	padding: 0;
	white-space: normal;
	*margin-left: -7px;
}

/** Normalization */
button,
input,
select,
textarea {
	font-size: 100%;
	margin: 0;
	vertical-align: baseline;
	*vertical-align: middle;
}

/** Addresses FF3/4 setting line-height on 'input' using !important in the UA stylesheet */
button,
input {
	line-height: normal; 
}

/** Spacing, pointer, styling for buttons */
button,
input[type="button"],
input[type="reset"],
input[type="submit"] {
	cursor: pointer;
	-webkit-appearance: button;
	*overflow: visible;
}

/** Re-set default cursor for disabled elements */
button[disabled],
input[disabled] {
	cursor: default;
}

/** IE Padding and sizing reset hacks */
input[type="checkbox"],
input[type="radio"] {
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing: border-box;
	padding: 0;
	*height: 13px;
	*width: 13px;
}

/** Normalization */
input[type="search"] {
	-webkit-appearance: textfield;
	-moz-box-sizing: content-box;
	-webkit-box-sizing: content-box;
	box-sizing: content-box;
}

/** Removes inner padding and search cancel button in S5, Chrome on OS X */
input[type="search"]::-webkit-search-decoration,
input[type="search"]::-webkit-search-cancel-button {
	-webkit-appearance: none;
}

/** Removes inner padding and border in FF3+ */
button::-moz-focus-inner,
input::-moz-focus-inner {
	border: 0;
	padding: 0;
}

/** Removes default vertical scrollbar in IE6/7/8/9 Improve readability. */
textarea {
	overflow: auto;
	vertical-align: top;
}

/** Remove most spacing between table cells */
table {
	border-collapse: collapse;
	border-spacing: 0;
}

input:focus,
select:focus,
textarea:focus,
button:focus {
    outline: none;
}

/* Universal
-------------------------------------------------------------- */

h2 { 
	font-size: 18px;
	color:#404449;
	font-weight:600;
	line-height: 1;
	padding:0.3em 0;
	margin:0;
}

p {
	padding: 0.2em 0 !important;
	margin:0;
}

html {height:100%;}

body {
	font-family: 'Open Sans', sans-serif;
	word-wrap: break-word;
	background:#fff;
	color: #3f454d;
	font-size:13px;
}

h2 > a {
	color: #404449 !important;
}

a {
    color : $LinkColor;
    text-decoration: none;
}

blockquote {
	color:#878a8c;
	margin:1em 0em !important;
	font-weight:300;
	font-size:14px;
	border-left:none !important;
	background:url(quote.png) top left no-repeat;
	background-size:58px 47px;
	min-height:47px;
}

#wsite-page-wrapper {
	box-shadow:0 0 10px rgba(0,0,0,0);
}

.menu-open #wsite-page-wrapper {
	box-shadow:0 0 10px rgba(0,0,0,0.2);
}

.wsite-mobile .wsite-multicol-table-wrap {
    margin: 0em 0 !important;
}

.wsite-mobile .wsite-button + div {
	display:none;
}

hr, hr.styled-hr {
	position: relative;
	left: -10px;
	-webkit-box-sizing: content-box;
	-moz-box-sizing: content-box;
	box-sizing: content-box;
	padding: 0px 10px;
	background: #cccccc;
}

/* Top Bar
-------------------------------------------------------------- */

#header {
	background-color: #fff;
	color: #3f454d;
	position: relative;
	padding: 9px 5px;
	z-index: 8;
	-webkit-box-shadow:  0px 1px 0px 0px rgba(35, 49, 66, 0.3);
    box-shadow:  0px 1px 0px 0px rgba(35, 49, 66, 0.3);
}
	
#header h1 {
	font-weight:normal;
	margin: 5px 0;
	padding: 0px 40px;
	font-size: 24px;
	line-height: 1.10;
	text-align:center;
}

#header a {
	color: #3f454d;
	font-weight:normal;
}

#header .wsite-menu-button, #header .wsite-home-link {
	float: left;
	margin-right: 5px;
	margin-left: 5px;
	cursor: pointer;
	border-radius:2px;
	text-decoration: none;
	background-clip: padding-box;
	-webkit-tap-highlight-color: rgba(0,0,0,0);
	position: absolute;
	top: 50%;
	margin-top:-17px;
}

#header .wsite-home-link {
	background:$LinkColor url(home-icon.png) top left no-repeat;
	background-size:20px 19px;
	width:19px;
	height:18px;
	right:15px;
	border-radius:0;
	margin-top:-9px;
}

#header .wsite-menu-button:active, .wsite-home-link:active, .menu-open #header .wsite-menu-button {
	border-radius:3px;
	background:#eee;
	box-shadow:inset 0 1px 2px rgba(0,0,0,0.1);
}
	
/* reusable button */
.wsite-menu-button, .menu-button {
	float: left;
	padding:  10px;
	margin-right: 5px;
	margin-left: 5px;
	cursor: pointer;
	text-decoration: none;
	background-clip: padding-box;
	-webkit-tap-highlight-color:rgba(0,0,0,0);
}

.wsite-menu-button-bars, .menu-button-bars {
	float: left;
	position: relative;
}
	
.wsite-menu-button-bar, .menu-button-bar {
	display: block;
	width: 1.125em;
	height: 2px;
	background-color: $LinkColor;
	-webkit-border-radius: 1px;
	-moz-border-radius: 1px;
	border-radius: 1px;
	margin-top: 3px;
}

.wsite-menu-button-bar:first-child, .menu-button-bar:first-child {
	margin-top:1px;
}
	
.wsite-menu-button-text, .menu-button-text {
	display: none;
}

.wsite-cart-link {
	height: 100%;
	right: 0;
	width: 20px;
	margin-right: 20px;
	position: absolute;
	top: 0;
}

.wsite-cart-link .wsite-cart-link-inner {
	background:url(icon-cart-$Color.png) no-repeat 0px 0px;
	width: 20px;
	height: 20px;
	display: inline-block;
	position: absolute;
	top: 50%;
	margin-top: -10px;
}

@media 
(-webkit-min-device-pixel-ratio: 2), 
(min-resolution: 192dpi) { 
	.wsite-cart-link .wsite-cart-link-inner {
		background-image:url(icon-cart-$Color-@2x.png);
        background-size:20px 20px;
	}
}

/* Homepage
-------------------------------------------------------------- */

.home-page #header {
	background: #fff;
	padding:35px 0px;
}

.home-page .wsite-home-link {
	display:none;
}

/* Navigation
-------------------------------------------------------------- */

.wsite-menu-wrapper {
	color:#424242;
	z-index: 2;
	background: url(sidebar-menu-bg.png) repeat left top;
}

.no-header-page .wsite-menu-wrapper,
.landing-page .wsite-menu-wrapper,
.header-page .wsite-menu-wrapper {
	top: 55px;
}

.wsite-mobile-menu li, .wsite-mobile-menu li:last-child {
	border:none;
}

.wsite-mobile-menu ul > li:first-child a, .wsite-mobile-menu ul > span:first-child li a {padding-top: 15px;}
.wsite-mobile-menu ul > li:last-child a, .wsite-mobile-menu ul > span:last-child li a {padding-bottom: 15px;}

.wsite-mobile-menu ul > li:first-child, .wsite-mobile-menu span:first-child > li {
	border-top:none !important;
}

.wsite-mobile-menu li a {
	font-weight:300;
	color: #424242;
	padding:15px 10px;
	font-size:18px;
	border-bottom: 1px solid #cbccce !important;
}

.wsite-mobile-menu li#active a,
.wsite-mobile-menu li a:active {
	background: $ButtonText !important;
	color: #fff;
	text-shadow:0 -1px 1px rgba(0,0,0,0.3);
	border-bottom: 1px solid $ButtonBorder !important;
	border-top: 1px solid $ButtonBorder !important;
	top: -1px;
	position: relative;
	padding: 15px 10px 14px;
}


.wsite-mobile-menu .wsite-menu-mobile-arrow {
	border: none;
	width:16px;
	height:16px;
	top: 5px;
	left:0;
	background:url(mobile-menu-arrow.png) top left no-repeat;
	background-size:16px 16px;
}

.wsite-mobile-menu li.wsite-menu-back-item .wsite-menu-mobile-arrow {
	top: 5px;
	border: none;
	background:url(mobile-menu-back.png) top left no-repeat;
	background-size:16px 16px;
}

.wsite-menu-back {padding-left:10px;}

/* Home navigation */

.home-page .wsite-mobile-menu {
	background:#fff;
	border:none;
}

.home-page .wsite-mobile-menu ul > li:first-child, .home-page .wsite-mobile-menu span:first-child > li {
	border-top:1px solid #cbccce;
}

.home-page .wsite-mobile-menu li a {
	color:#424242;
	display:block;
	padding:15px 20px;
}

.home-page .wsite-mobile-menu li#active a, .home-page .wsite-mobile-menu ul > li:first-child#active a,
.home-page .wsite-mobile-menu li a:active, .home-page .wsite-mobile-menu span:first-child > li a:active {
	background: $ButtonText !important;
	color: #fff;
	text-shadow:0 -1px 1px rgba(0,0,0,0.3);
	border-bottom: 1px solid $ButtonBorder !important;
	border-top: 1px solid $ButtonBorder !important;
	top: -1px;
	position: relative;
	padding:15px 20px 14px;
}

/* Social Icons
-------------------------------------------------------------- */
.wsite-social a {
	width:40px;
	height:40px;
	margin: 5px 10px 5px 0px;
	float:left;
	border:1px solid #aeb1b7;
	border-radius:3px;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing: border-box;
	-webkit-box-shadow: 0px 1px 2px rgba(0, 0, 0, 0.1);
	-moz-box-shadow: 0px 1px 2px rgba(0, 0, 0, 0.1);
	box-shadow: 0px 1px 2px rgba(0, 0, 0, 0.1);
	background: #f7f8f9; /* Old browsers */
	background: -moz-linear-gradient(top,  #fff 0%, #f7f8f9 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#fff), color-stop(100%,#f7f8f9)); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  #fff 0%,#f7f8f9 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  #fff 0%,#f7f8f9 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  #fff 0%,#f7f8f9 100%); /* IE10+ */
	background: linear-gradient(to bottom,  #fff 0%,#f7f8f9 100%); /* W3C */
	filter: #f7f8f9;/*progid:DXImageTransform.Microsoft.gradient( startColorstr='#f7f8f9', endColorstr='#f7f8f9',GradientType=0 );  IE6-9 */
    -webkit-tap-highlight-color: rgba(0,0,0,0)
}
.wsite-social a:active {
	background: #ffffff;
	background: -moz-linear-gradient(top,  #d7d7d7 0%, #ebebeb 100%);
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#d7d7d7), color-stop(100%,#ebebeb));
	background: -webkit-linear-gradient(top,  #d7d7d7 0%,#ebebeb 100%);
	background: -o-linear-gradient(top,  #d7d7d7 0%,#ebebeb 100%);
	background: -ms-linear-gradient(top,  #d7d7d7 0%,#ebebeb 100%);
	background: linear-gradient(to bottom,  #d7d7d7 0%,#ebebeb 100%);
	filter: #ffffff;/*progid:DXImageTransform.Microsoft.gradient( startColorstr='#d7d7d7', endColorstr='#ebebeb',GradientType=0 );*/
	border:1px solid #b5b6ba;
	﻿-webkit-box-shadow:  none;
    box-shadow:  none;
}

.wsite-social a span {
	display:block;
	width:40px;
	height:40px;
}

.wsite-social a.wsite-social-item.first-child,
.wsite-social a.wsite-social-item.last-child {
	margin:5px 10px 5px 0px !important;
}

.wsite-social-rss span { background: url(social-icons.png) no-repeat -281px 0px; }
.wsite-social-linkedin span { background: url(social-icons.png) no-repeat -41px 0px; }
.wsite-social-facebook span { background: url(social-icons.png) no-repeat -1px 0px; }
.wsite-social-twitter span { background: url(social-icons.png) no-repeat -81px 0px; }
.wsite-social-mail span { background: url(social-icons.png) no-repeat -201px 0px; }
.wsite-social-pinterest span { background: url(social-icons.png) no-repeat -321px 0px; }
.wsite-social-youtube span { background: url(social-icons.png) no-repeat -241px 0px; }
.wsite-social-plus span { background: url(social-icons.png) no-repeat -161px 0px; }
.wsite-social-flickr span { background: url(social-icons.png) no-repeat -401px 0px; }
.wsite-social-vimeo span { background: url(social-icons.png) no-repeat -121px 0px; }
.wsite-social-yahoo span { background: url(social-icons.png) no-repeat -361px 0px; }

.wsite-menu-wrapper .wsite-social {
	padding:1em 0em 1em 0.65em;
}

.wsite-social, .wsite-editor .wsite-social {
	white-space:normal;
}

@media 
(-webkit-min-device-pixel-ratio: 2), 
(min-resolution: 192dpi) { 

	.wsite-social a span {
		background-image: url(social-icons@2x.png);
		    -moz-background-size:440px 40px;
             -ie-background-size:440px 40px;
              -o-background-size:440px 40px;
         -webkit-background-size:440px 40px;
                 background-size:440px 40px;
	}
	
}

/* Sidebar Phone
-------------------------------------------------------------- */

#phone .wsite-text {
	font-size:18px;
	padding:15px 10px 0px 10px;
	color:#777777;
	font-weight:400;
	display:block;
}

/* Sidebar Search
-------------------------------------------------------------- */
#search .wsite-search {
	border:none;
	box-shadow:none;
	padding: 10px 30px 12px 6px;
	background:#edeef1;
	margin:0px;
}

#search .wsite-search .wsite-search-input {
	background:none;
	border:none;
	font-family: 'Open Sans', sans-serif;
	font-size:16px;
	color:#9a9ca4;
	padding-left:0px;
	box-shadow:none;
	height:24px;
}

#search .wsite-search .wsite-search-button, .wsite-search-element-submit, .wsite-editor .wsite-search-element-submit,
#search .wsite-search .wsite-search-button:hover, .wsite-search-element-submit:hover, .wsite-editor .wsite-search-element-submit:hover,
#search .wsite-search .wsite-search-button:active, .wsite-search-element-submit:active, .wsite-editor .wsite-search-element-submit:active {
	background: url(search-light.png) top left ;
	width: 13px;
	height: 14px;
	position: absolute;
	top: 50%;
	margin-top: -7px;
	right: 10px;
	cursor: pointer;
}

@media 
(-webkit-min-device-pixel-ratio: 2), 
(min-resolution: 192dpi) { 

	#search .wsite-search .wsite-search-button, .wsite-search-element-submit, .wsite-editor .wsite-search-element-submit,
	#search .wsite-search .wsite-search-button:hover, .wsite-search-element-submit:hover, .wsite-editor .wsite-search-element-submit:hover,
	#search .wsite-search .wsite-search-button:active, .wsite-search-element-submit:active, .wsite-editor .wsite-search-element-submit:active {
			background: url(search-light-@2x.png) top left;
		    -moz-background-size:40px 14px;
             -ie-background-size:40px 14px;
              -o-background-size:40px 14px;
         -webkit-background-size:40px 14px;
                 background-size:40px 14px;
	}
	
}

/* Landing Page
-------------------------------------------------------------- */
.landing-container {
	padding:20px;
	-webkit-box-shadow:  0 1px 1px rgba(0,0,0,0.1);
    box-shadow:  0 1px 1px rgba(0,0,0,0.1), 0 1px 25px rgba(0,0,0,0.08);
	border-bottom:1px solid #B2B2B2; 
}

.landing-container h2 {
	padding: 0em;
	font-size: 22px;
}

.landing-container p {
	margin:1em 0em;
	font-size:1.1em;
}

.wsite-header {
	width: 100%;
	height: 138px;
	background: url(landing-banner.jpg) no-repeat;
	background-size: 100%;
}

/* Content
-------------------------------------------------------------- */
#content-wrapper {
    margin: 0px;
}

.wsite-mobile .wsite-not-footer .wsite-multicol-table, .wsite-mobile .wsite-not-footer .wsite-multicol-tbody, 
.wsite-mobile .wsite-not-footer .wsite-multicol-tr, .wsite-mobile .wsite-not-footer .wsite-multicol-col {
	margin: 0 !important;
}

#content {
	min-height:50px;
	position:relative;
}

#content2 {
	padding:0 10px;
}

.wsite-elements,
#content .weebly-area.wsite-not-footer .weebly-content-area{
	padding:15px 10px 10px 10px !important;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing:border-box;
	position:relative; z-index:3;
	margin:0 !important;
	min-height: 50px;
}

/* Gallery
-------------------------------------------------------------- */
html body .galleryImageBorder, html body a .galleryImageBorder, 
#icontent .galleryImageBorder, #icontent a .galleryImageBorder, 
.wsite-mobile .wsite-image {
	background:none;
	border-radius:2px;
	border:none !important;
	padding:0px !important;
}

html body .galleryImageBorder a, html body a .galleryImageBorder a,
#icontent .galleryImageBorder > div:first-child, #icontent a .galleryImageBorder > div:first-child, 
.wsite-mobile .wsite-image a {
	position:relative !important;
	display:block !important;
}

.wsite-mobile .wsite-image {
	padding:0px !important;
}

.wsite-mobile .wsite-image img {
	padding:0px !important;
}

.wsite-mobile .wsite-image a {
	padding:0px !important;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing:border-box;
	border-radius:2px;
	-webkit-tap-highlight-color:rgba(0,0,0,0); 
}

html body .galleryImageBorder > div, html body a .galleryImageBorder > div {
	border-radius:2px;
}

html body .galleryImageBorder a img {
	display:block !important;
	border-radius:2px;
	border:none !important;
}

html body a .galleryImageBorder a img,
body .wsite-image-border-hairline a img, body .wsite-image-border-thin a img, body .wsite-image-border-medium a img, body .wsite-image-border-thick a img {
	display:block !important;
	position:static !important;
	border-radius:2px;
	border:none !important;
}

/* Footer
-------------------------------------------------------------- */
.wsite-mobile .weebly-area.wsite-footer, .wsite-mobile-footer {
border-top: none;
}

.wsite-footer, .wsite-footer-version, .wsite-mobile #weeblyfootertext, .wsite-mobile .wsite-footer, .wsite-footer-version {
	border-top:none; 
	background:#646567;
	color:#c2c3c4;
	text-shadow:none;
}

.wsite-footer h2, .wsite-footer a, .wsite-footer-version a {
	color:#fff;
}

.wsite-footer .wsite-social a {
	border:1px solid #444;
}

.wsite-footer hr.styled-hr {
    background: none repeat scroll 0 0 #A2A3A5;
}

.wsite-footer blockquote {
	color:#a3a8ae;
	margin-left:10px !important;
	background:url(footer-quote.png) top left no-repeat;
	background-size:58px 47px;
}
.wsite-footer .wsite-form-input,
.wsite-footer .wsite-search-element-input{
    border: 1px solid #404345;
    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.12) inset;
    color: #333;
    padding: 8px ;
	
	background: #f4f5f5; /* Old browsers */
	background: -moz-linear-gradient(top,  #f4f5f5 0%, #f9fafa 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#f4f5f5), color-stop(100%,#f9fafa)); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  #f4f5f5 0%,#f9fafa 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  #f4f5f5 0%,#f9fafa 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  #f4f5f5 0%,#f9fafa 100%); /* IE10+ */
	background: linear-gradient(to bottom,  #f4f5f5 0%,#f9fafa 100%); /* W3C */
	filter: #f4f5f5;/*progid:DXImageTransform.Microsoft.gradient( startColorstr='#f4f5f5', endColorstr='#f9fafa',GradientType=0 );  IE6-9 */
}

.wsite-footer .wsite-button, .wsite-footer .wsite-button-large.wsite-button-highlight, .wsite-footer .wsite-button-large.wsite-button-highlight:hover, 
.wsite-footer .wsite-button:hover, .wsite-footer .wsite-button:active,
.wsite-footer .wsite-button-large, .wsite-footer .wsite-button-large:hover, .wsite-footer .wsite-button-large:active,
.wsite-footer .wsite-phone-number .wsite-m-button, .wsite-footer .wsite-opentable .wsite-m-button {
	border:1px solid #39393a;
}

.wsite-footer .wsite-button:active, .wsite-footer .wsite-button-large:active,
.wsite-footer .wsite-button-highlight:active, 
.wsite-footer .wsite-button-large.wsite-button-highlight:active {
	-webkit-box-shadow:  0px 1px 1px 0px rgba(255, 255, 255, .31);
    box-shadow:  0px 1px 1px 0px rgba(255, 255, 255, .31), inset 0 1px 1px rgba(0,0,0,0.2);
}

.wsite-footer .wsite-form-label,
.wsite-footer input[type="checkbox"]:checked + label,
.wsite-footer input[type="radio"]:checked + label {
	color:#fff;
}

.wsite-footer .form-radio-container label:before {
    background-image: url("footer-formelements-$Color.png");
}

@media 
(-webkit-min-device-pixel-ratio: 2), 
(min-resolution: 192dpi) { 

	.wsite-footer .form-radio-container label:before {
		background-image: url("footer-formelements-$Color-@2x.png");
		    -moz-background-size:44px;
             -ie-background-size:44px;
              -o-background-size:44px;
         -webkit-background-size:44px;
                 background-size:44px;
	}
	
}

.wsite-footer-separator {
	border:none;
	border-bottom:1px solid #a2a3a4;
}

/* Form
-------------------------------------------------------------- */
.weebly-form-input, .wsite-form-input, .wsite-search-element-input, .wsite-editor .weebly-form-input, .wsite-editor .wsite-form-input, 
.wsite-editor .wsite-search-input, #commentPostDiv .field input[type=text], #commentPostDiv .field textarea {
	background: #f9fafa;
	border: 1px solid #b5b6ba;
	border-radius:2px;
	padding: 8px !important;
	font-family: 'Open Sans', sans-serif;
	font-weight:400;
	font-size:16px;
	color:#333;
	-webkit-box-shadow: inset 0px 1px 2px 0px rgba(0, 0, 0, 0.2);
    box-shadow: inset 0px 1px 2px 0px rgba(0, 0, 0, 0.2);
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing:border-box;
}

.weebly-form-input:focus, .wsite-form-input:focus, .wsite-search-element-input:focus, .wsite-editor .weebly-form-input:focus, 
.wsite-editor .wsite-form-input:focus, .wsite-editor .wsite-search-input:focus,
#commentPostDiv .field input[type=text]:focus, #commentPostDiv .field textarea:focus {
	background:#fff;
	border:1px solid $LinkColor;
}

.wsite-form-field .wsite-form-input-country select,
.wsite-form-field .wsite-form-input-state  select {
	height: 40px;
	padding: 0 15px !important;
	background-position: right 15px, 0, 100%;
}

.wsite-form-field select {
    width: 100%;
	border: 1px solid #b5b6ba;
	border-radius:3px;
	padding: 9px 15px !important;
	height:50px;
	font-family: 'Open Sans', sans-serif;
	font-size:16px;
	font-weight:400;
	color:#51555a;
	background: #f2f2f2;
	background: url(arrow.png) right 21px no-repeat, -moz-linear-gradient(top,  #ffffff 0%, #f2f2f2 100%);
	background: url(arrow.png) right 21px no-repeat, -webkit-gradient(linear, left top, left bottom, color-stop(0%,#ffffff), color-stop(100%,#f2f2f2));
	background: url(arrow.png) right 21px no-repeat, -webkit-linear-gradient(top,  #ffffff 0%,#f2f2f2 100%);
	background: url(arrow.png) right 21px no-repeat, -o-linear-gradient(top,  #ffffff 0%,#f2f2f2 100%);
	background: url(arrow.png) right 21px no-repeat, -ms-linear-gradient(top,  #ffffff 0%,#f2f2f2 100%);
	background: url(arrow.png) right 21px no-repeat, linear-gradient(to bottom,  #ffffff 0%,#f2f2f2 100%);
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#ffffff', endColorstr='#f2f2f2',GradientType=0 );
	background-size:25px 8px, 100% 100%;
	-webkit-box-shadow: none;
    box-shadow: none;
   -webkit-appearance: none;
}
.wsite-form-label {
	font-weight:normal;
	color:#51555a;
}

.wsite-form-field {
	margin-bottom:2em;
}

.weebly-form-sublabel, .wsite-form-sublabel {
    font-size: 11px;
}

input[type="radio"], input[type="checkbox"]:not(#commentNotify) {
    left: -999em;
    position: absolute;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
    box-sizing: border-box;
}

input[type="checkbox"] + label:before { background-position: 0 -22px;}
input[type="checkbox"]:checked + label:before {background-position: 0 0 ; }
		 
input[type="radio"] + label:before { background-position: -22px -22px;}	 	
input[type="radio"]:checked + label:before { background-position: -22px 0;}

input[type="checkbox"]:checked + label,
input[type="radio"]:checked + label{
	color:#101215;
}

.form-radio-container label:before {
    background-image: url("formelements-$Color.png");
    content: "";
    display: inline-block;
    height: 22px;
    left: -5px;
	margin-left: 5px;
    position: relative;
    top: 7px;
    width: 22px;
}

@media 
(-webkit-min-device-pixel-ratio: 2), 
(min-resolution: 192dpi) { 

	.form-radio-container label:before {
		background-image: url("formelements-$Color-@2x.png");
		    -moz-background-size:44px;
             -ie-background-size:44px;
              -o-background-size:44px;
         -webkit-background-size:44px;
                 background-size:44px;
	}
	
}

.form-radio-container, .wsite-editor .form-radio-container {
	margin: 0px 0px 2px 0px !important;
}

.wsite-phone-field .wsite-form-phone-separator {
	line-height: 35px;
}

/* Buttons
-------------------------------------------------------------- */
.wsite-button {
	color: $ButtonText !important;
	border-radius: 3px;
	text-shadow: 0px 1px 0px rgba(255, 255, 255, 0.22);
	-webkit-tap-highlight-color: rgba(0,0,0,0)
}

.wsite-button, .wsite-button:hover,
.wsite-button-large, .wsite-button-large:hover {
	background: #ffffff;
	background: -moz-linear-gradient(top,  #ffffff 0%, #f2f2f2 100%);
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#ffffff), color-stop(100%,#f2f2f2));
	background: -webkit-linear-gradient(top,  #ffffff 0%,#f2f2f2 100%);
	background: -o-linear-gradient(top,  #ffffff 0%,#f2f2f2 100%);
	background: -ms-linear-gradient(top,  #ffffff 0%,#f2f2f2 100%);
	background: linear-gradient(to bottom,  #ffffff 0%,#f2f2f2 100%);
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#ffffff', endColorstr='#f2f2f2',GradientType=0 );
	border:1px solid #b5b6ba;
	﻿-webkit-box-shadow:  0px 1px 2px 0px rgba(0, 0, 0, 0.1);
    box-shadow:  0px 1px 2px 0px rgba(0, 0, 0, 0.1);
}

.wsite-button:active,
.wsite-button-large:active {
	background: #ffffff;
	background: -moz-linear-gradient(top,  #d7d7d7 0%, #ebebeb 100%);
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#d7d7d7), color-stop(100%,#ebebeb));
	background: -webkit-linear-gradient(top,  #d7d7d7 0%,#ebebeb 100%);
	background: -o-linear-gradient(top,  #d7d7d7 0%,#ebebeb 100%);
	background: -ms-linear-gradient(top,  #d7d7d7 0%,#ebebeb 100%);
	background: linear-gradient(to bottom,  #d7d7d7 0%,#ebebeb 100%);
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#d7d7d7', endColorstr='#ebebeb',GradientType=0 );
	border:1px solid #b5b6ba;
	﻿-webkit-box-shadow:  none;
    box-shadow: inset 0 1px 1px rgba(0,0,0,0.1);
	text-shadow: 0px 1px 0px rgba(255, 255, 255, 0.22);
}

.wsite-button-highlight, .wsite-button-highlight:hover, 
.wsite-button-large.wsite-button-highlight, .wsite-button-large.wsite-button-highlight:hover {
	background: $ButtonStartColor;
	background: -moz-linear-gradient(top,  $ButtonStartColor 0%, $ButtonEndColor 100%);
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,$ButtonStartColor), color-stop(100%,$ButtonEndColor));
	background: -webkit-linear-gradient(top,  $ButtonStartColor 0%,$ButtonEndColor 100%);
	background: -o-linear-gradient(top,  $ButtonStartColor 0%,$ButtonEndColor 100%);
	background: -ms-linear-gradient(top,  $ButtonStartColor 0%,$ButtonEndColor 100%);
	background: linear-gradient(to bottom,  $ButtonStartColor 0%,$ButtonEndColor 100%);
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$ButtonStartColor', endColorstr='$ButtonEndColor',GradientType=0 );
	border:1px solid $ButtonBorder;
	﻿-webkit-box-shadow:  0px 1px 2px 0px rgba(0, 0, 0, 0.2);
    box-shadow:  0px 1px 2px 0px rgba(0, 0, 0, 0.2);
	color: #fff !important;
	text-shadow: 0px -1px 0px rgba(0, 0, 0, 0.22);
}

.wsite-button-highlight:active, 
.wsite-button-large.wsite-button-highlight:active {
	background: $PressedStartColor;
	background: -moz-linear-gradient(top,  $PressedStartColor 0%, $PressedEndColor 100%);
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,$PressedStartColor), color-stop(100%,$PressedEndColor));
	background: -webkit-linear-gradient(top,  $PressedStartColor 0%,$PressedEndColor 100%);
	background: -o-linear-gradient(top,  $PressedStartColor 0%,$PressedEndColor 100%);
	background: -ms-linear-gradient(top,  $PressedStartColor 0%,$PressedEndColor 100%);
	background: linear-gradient(to bottom,  $PressedStartColor 0%,$PressedEndColor 100%);
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$PressedStartColor', endColorstr='$PressedEndColor',GradientType=0 );
	border:1px solid $ButtonBorder;
	﻿-webkit-box-shadow:  none;
    box-shadow: inset 0 1px 1px rgba(0,0,0,0.3);
	color: #fff !important;
	text-shadow: 0px -1px 0px rgba(0, 0, 0, 0.22);
}

.wsite-button-inner, .wsite-button-large .wsite-button-inner, 
.wsite-button-highlight .wsite-button-inner, 
.wsite-button-large.wsite-button-highlight .wsite-button-inner {
	background:none !important;
}

.wsite-button-inner:active, .wsite-button-large .wsite-button-inner:active, 
.wsite-button-highlight .wsite-button-inner:active, 
.wsite-button-large.wsite-button-highlight .wsite-button-inner:active{
	box-shadow:none !important;
}

/* Location
-------------------------------------------------------------- */
.wsite-location div:not(.wsite-hide-map) {
	padding:6px 6px 0px;	
	border-radius:3px;
	border: 1px solid #b5b6ba;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing:border-box;
	background: #fafafa;
	text-align:center;
	-webkit-box-shadow: 0px 1px 4px 0px rgba(0, 0, 0, 0.18);
	box-shadow: 0px 1px 4px 0px rgba(0, 0, 0, 0.18);
}

.wsite-location div:not(.wsite-hide-map) a.wsite-m-button {
	border:none;
	box-shadow:none;
	font-weight: 500;
	background:none;
	color: #595b5e;
	font-size: 12px;
	font-family: 'Roboto', sans-serif;
	padding:10px 0;
	display:block;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing:border-box;
}

.wsite-location img {
	margin-top:0px;
	border-radius:3px;
	-webkit-box-shadow: inset 0px 2px 7px 7px rgba(255, 255, 255, 0.68);
	box-shadow: inset 0px 2px 7px 7px rgba(255, 255, 255, 0.68);
}

/* Mobile Buttons (common)
-------------------------------------------------------------- */
.wsite-phone-number .wsite-m-button, .wsite-opentable .wsite-m-button, .wsite-location .wsite-hide-map .wsite-m-button {
	background: rgb(255,255,255); /* Old browsers */
	/* IE9 SVG, needs conditional override of 'filter' to 'none' */
	background: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiA/Pgo8c3ZnIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdmlld0JveD0iMCAwIDEgMSIgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSI+CiAgPGxpbmVhckdyYWRpZW50IGlkPSJncmFkLXVjZ2ctZ2VuZXJhdGVkIiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIgeDE9IjAlIiB5MT0iMCUiIHgyPSIwJSIgeTI9IjEwMCUiPgogICAgPHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2ZmZmZmZiIgc3RvcC1vcGFjaXR5PSIxIi8+CiAgICA8c3RvcCBvZmZzZXQ9IjEwMCUiIHN0b3AtY29sb3I9IiNmMGYxZjMiIHN0b3Atb3BhY2l0eT0iMSIvPgogIDwvbGluZWFyR3JhZGllbnQ+CiAgPHJlY3QgeD0iMCIgeT0iMCIgd2lkdGg9IjEiIGhlaWdodD0iMSIgZmlsbD0idXJsKCNncmFkLXVjZ2ctZ2VuZXJhdGVkKSIgLz4KPC9zdmc+);
	background: url(callus-icon.png) no-repeat 15px center -moz-linear-gradient(top,  rgba(255,255,255,1) 0%, rgba(240,241,243,1) 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(255,255,255,1)), color-stop(100%,rgba(240,241,243,1))); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  rgba(255,255,255,1) 0%,rgba(240,241,243,1) 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  rgba(255,255,255,1) 0%,rgba(240,241,243,1) 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  rgba(255,255,255,1) 0%,rgba(240,241,243,1) 100%); /* IE10+ */
	background: linear-gradient(to bottom,  rgba(255,255,255,1) 0%,rgba(240,241,243,1) 100%); /* W3C */
	 filter: rgb(255,255,255); /*progid:DXImageTransform.Microsoft.gradient( startColorstr='#ffffff', endColorstr='#f0f1f3',GradientType=0 );*/ /* IE6-8 */
	
    border: 1px solid #b5b6ba;
    border-radius: 25px;
    box-shadow: none;
    color: $ButtonText;
    font-weight: normal;
	display:inline-block;
	padding: 5px 0px;
	width:100%;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing:border-box;
    text-decoration: none;
    text-shadow: none;
	font-family: 'Open Sans', sans-serif;
	font-weight: 600;
	font-size: 16px !important;
	text-align:center;
	line-height:30px;
	-webkit-tap-highlight-color: rgba(0,0,0,0)
}

.wsite-phone-number .wsite-m-button:active, .wsite-opentable .wsite-m-button:active, .wsite-location .wsite-hide-map .wsite-m-button:active {
	background: #ffffff;
	background: -moz-linear-gradient(top,  #d7d7d7 0%, #ebebeb 100%);
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#d7d7d7), color-stop(100%,#ebebeb));
	background: -webkit-linear-gradient(top,  #d7d7d7 0%,#ebebeb 100%);
	background: -o-linear-gradient(top,  #d7d7d7 0%,#ebebeb 100%);
	background: -ms-linear-gradient(top,  #d7d7d7 0%,#ebebeb 100%);
	background: linear-gradient(to bottom,  #d7d7d7 0%,#ebebeb 100%);
	filter: #ffffff /*progid:DXImageTransform.Microsoft.gradient( startColorstr='#d7d7d7', endColorstr='#ebebeb',GradientType=0 );*/
}

.wsite-location .wsite-show-map .wsite-m-button, .wsite-location .wsite-show-map .wsite-m-button:active {
	filter: #ffffff;
}

/* Call Us
-------------------------------------------------------------- */
.wsite-phone-number .wsite-m-button span {
	display:block;
	background:url(callus-icon-$Color.png) no-repeat 10px center;
}

@media 
(-webkit-min-device-pixel-ratio: 2), 
(min-resolution: 192dpi) { 

	.wsite-phone-number .wsite-m-button span {
		background-image: url("callus-icon-$Color-@2x.png");
		    -moz-background-size:18px;
             -ie-background-size:18px;
              -o-background-size:18px;
         -webkit-background-size:18px;
                 background-size:18px;
	}
	
}


/* Reserve a Table
-------------------------------------------------------------- */
.wsite-opentable .wsite-m-button span {
	display:block;
	background:url(reserve-table-icon-$Color.png) no-repeat 7px center;
}

@media 
(-webkit-min-device-pixel-ratio: 2), 
(min-resolution: 192dpi) { 

	.wsite-opentable .wsite-m-button span {
		background-image: url("reserve-table-icon-$Color-@2x.png");
		    -moz-background-size:27px 14px;
             -ie-background-size:27px 14px;
              -o-background-size:27px 14px;
         -webkit-background-size:27px 14px;
                 background-size:27px 14px;
	}
	
}

/* Directions 
-------------------------------------------------------------- */
.wsite-location .wsite-hide-map .wsite-m-button span {
	display:block;
	background:url(directions-icon-$Color.png) no-repeat 10px center;
}

@media 
(-webkit-min-device-pixel-ratio: 2), 
(min-resolution: 192dpi) { 

	.wsite-location .wsite-hide-map .wsite-m-button span {
		background-image: url("directions-icon-$Color-@2x.png");
		    -moz-background-size:22px 21px;
             -ie-background-size:22px 21px;
              -o-background-size:22px 21px;
         -webkit-background-size:22px 21px;
                 background-size:22px 21px;
	}
	
}


/* Commenting 
-------------------------------------------------------------- */
.blogCommentWrap {
	margin: 0 0 22px 0;
	padding: 10px;
	word-wrap: break-word;
	background:#fff;
	border:1px solid #ddd;
	box-shadow:0 1px 3px rgba(0,0,0,0.1)
}

h2#commentReplyTitle {
	font-size: 15px;
	text-transform:uppercase;
	color:#404449;
	font-weight:600;
	font-family: 'Open Sans', sans-serif;
	text-align:center;

}

.blogCommentHeading {
	font-family: 'Open Sans', sans-serif;
	margin: 0 0 10px 0;
	padding:0 0 10px 0;
	border-bottom:1px solid #ddd;
	background:#fff;
}

.blogCommentHeading .blogCommentHeadingInner {
	height: 25px;
	background: #fff;
}

.blogCommentHeading .blogCommentAuthor {
	float: left;
	color: #404449;
	font-weight: bold;
	font-size: 14px;
	height:25px;
	padding: 0;
	background: none;
}

.blogCommentHeading .blogCommentAuthor span.name, .blogCommentHeading .blogCommentAuthor a.name, .blogCommentHeading .blogCommentAuthor span.email {
	float: left;
	height: 25px;
	text-shadow: white 1px 1px 0;
	font-family: 'Open Sans', sans-serif;
	font-weight:600;
}

.blogCommentHeading .blogCommentDate {
	float: right;
	text-align: right;
	font-size: 12px;
	color: #404449;
	text-shadow: white 1px 1px 0;
	height: 25px;
	line-height:25px;
	padding: 0;
	margin: 0;
}

.blogCommentHeading .blogCommentAuthor span.name, .blogCommentHeading .blogCommentAuthor a.name, .blogCommentHeading .blogCommentAuthor span.email {
	float: left;
	height: 25px;
	line-height: 25px;
	text-shadow: white 1px 1px 0;
}

.blogCommentOwner .blogCommentHeading .blogCommentAuthor {
	background-image: none;
}

.blogCommentText {
padding: 0 ;
}

.blogCommentOwner, .blogCommentOwner .blogCommentHeading, .blogCommentOwner .blogCommentHeadingInner {
background-image: none;
}

.blogCommentHeading .blogCommentAuthor a.link {
	margin: 5px 3px 0 0;
}

.blog-button {
	font-family: "Helvetica Neue", Helvetica, Arial;
	height: 23px;
	color: #333;
	font-size: 11px;
	font-weight: bold;
	cursor: pointer;
	line-height: 23px;
	background:#fff;
	border:1px solid #ccc;
	border-radius:3px;
}

.blog-button span {
	float: left;
	height: 100%;
	background: none;
	margin: 0 0 0 7px;
	padding: 0 15px 0 8px;
}

.wsite-mobile iframe {
	margin: 0 !important;
}

#commentPostDiv .commentInput, #commentPostDiv .commentTextarea {
	padding: 0 0 0 0;
	margin-left:12px;
}
.blogCommentSubreplyWrapper div.iframeWrapper {
	background: #fff;
	border:none;
	border-top: solid #e3e3e3 1px;
	border-radius: 0px;
	-moz-border-radius: 0px;
	-webkit-border-radius: 0px;
}

#commentPostDiv .field input[type=text] {
	height: 32px;
	line-height: 32px;
}

.blogCommentSubreplyWrapper iframe {
	padding: 15px 0 0 0;
}
.blogCommentLevel1 {border-left:8px solid #ddd;}
.blogCommentLevel2 {border-left:16px solid #ddd;}
.blogCommentLevel3 {border-left:24px solid #ddd;}
.blogCommentLevel4 {border-left:32px solid #ddd;}
.blogCommentLevel5 {border-left:40px solid #ddd;}
.blogCommentLevel6 {border-left:48px solid #ddd;}
.blogCommentLevel7 {border-left:56px solid #ddd;}
.blogCommentLevel8 {border-left:64px solid #ddd;}
.blogCommentLevel9 {border-left:72px solid #ddd;}